# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: regfile.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'regfile.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fown_pb2 as fown__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rregfile.proto\x1a\nopts.proto\x1a\nfown.proto\"\x89\x02\n\x0ereg_file_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x1f\n\x05\x66lags\x18\x02 \x02(\rB\x10\xd2?\r\x1a\x0brfile.flags\x12\x0b\n\x03pos\x18\x03 \x02(\x04\x12\x19\n\x04\x66own\x18\x05 \x02(\x0b\x32\x0b.fown_entry\x12\x0c\n\x04name\x18\x06 \x02(\t\x12\x12\n\x06mnt_id\x18\x07 \x01(\x11:\x02-1\x12\x0c\n\x04size\x18\x08 \x01(\x04\x12\x0b\n\x03\x65xt\x18\t \x01(\x08\x12\x0c\n\x04mode\x18\n \x01(\r\x12\x10\n\x08\x62uild_id\x18\x0b \x03(\r\x12\x10\n\x08\x63hecksum\x18\x0c \x01(\r\x12\x17\n\x0f\x63hecksum_config\x18\r \x01(\r\x12\x1a\n\x12\x63hecksum_parameter\x18\x0e \x01(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'regfile_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REG_FILE_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_REG_FILE_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\r\032\013rfile.flags'
  _globals['_REG_FILE_ENTRY']._serialized_start=42
  _globals['_REG_FILE_ENTRY']._serialized_end=307
# @@protoc_insertion_point(module_scope)



# Autogenerated. Do not edit!
from .apparmor_pb2 import *
from .autofs_pb2 import *
from .binfmt_misc_pb2 import *
from .bpfmap_data_pb2 import *
from .bpfmap_file_pb2 import *
from .cgroup_pb2 import *
from .core_aarch64_pb2 import *
from .core_arm_pb2 import *
from .core_loongarch64_pb2 import *
from .core_mips_pb2 import *
from .core_ppc64_pb2 import *
from .core_riscv64_pb2 import *
from .core_s390_pb2 import *
from .core_x86_pb2 import *
from .core_pb2 import *
from .cpuinfo_pb2 import *
from .creds_pb2 import *
from .eventfd_pb2 import *
from .eventpoll_pb2 import *
from .ext_file_pb2 import *
from .fdinfo_pb2 import *
from .fh_pb2 import *
from .fifo_pb2 import *
from .file_lock_pb2 import *
from .fown_pb2 import *
from .fs_pb2 import *
from .fsnotify_pb2 import *
from .ghost_file_pb2 import *
from .img_streamer_pb2 import *
from .inventory_pb2 import *
from .ipc_desc_pb2 import *
from .ipc_msg_pb2 import *
from .ipc_sem_pb2 import *
from .ipc_shm_pb2 import *
from .ipc_var_pb2 import *
from .macvlan_pb2 import *
from .memfd_pb2 import *
from .mm_pb2 import *
from .mnt_pb2 import *
from .netdev_pb2 import *
from .ns_pb2 import *
from .packet_sock_pb2 import *
from .pagemap_pb2 import *
from .pidfd_pb2 import *
from .pidns_pb2 import *
from .pipe_data_pb2 import *
from .pipe_pb2 import *
from .pstree_pb2 import *
from .regfile_pb2 import *
from .remap_file_path_pb2 import *
from .rlimit_pb2 import *
from .rseq_pb2 import *
from .sa_pb2 import *
from .seccomp_pb2 import *
from .siginfo_pb2 import *
from .signalfd_pb2 import *
from .sit_pb2 import *
from .sk_inet_pb2 import *
from .sk_netlink_pb2 import *
from .sk_opts_pb2 import *
from .sk_packet_pb2 import *
from .sk_unix_pb2 import *
from .stats_pb2 import *
from .sysctl_pb2 import *
from .tcp_stream_pb2 import *
from .time_pb2 import *
from .timens_pb2 import *
from .timer_pb2 import *
from .timerfd_pb2 import *
from .tty_pb2 import *
from .tun_pb2 import *
from .userns_pb2 import *
from .utsns_pb2 import *
from .vma_pb2 import *



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: rpc.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'rpc.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\trpc.proto\"O\n\x15\x63riu_page_server_info\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x0b\n\x03pid\x18\x03 \x01(\x05\x12\n\n\x02\x66\x64\x18\x04 \x01(\x05\"/\n\x0e\x63riu_veth_pair\x12\r\n\x05if_in\x18\x01 \x02(\t\x12\x0e\n\x06if_out\x18\x02 \x02(\t\")\n\rext_mount_map\x12\x0b\n\x03key\x18\x01 \x02(\t\x12\x0b\n\x03val\x18\x02 \x02(\t\"@\n\x0ejoin_namespace\x12\n\n\x02ns\x18\x01 \x02(\t\x12\x0f\n\x07ns_file\x18\x02 \x02(\t\x12\x11\n\textra_opt\x18\x03 \x01(\t\"%\n\ninherit_fd\x12\x0b\n\x03key\x18\x01 \x02(\t\x12\n\n\x02\x66\x64\x18\x02 \x02(\x05\")\n\x0b\x63group_root\x12\x0c\n\x04\x63trl\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x02(\t\"\x18\n\x07unix_sk\x12\r\n\x05inode\x18\x01 \x02(\r\"\xa7\r\n\tcriu_opts\x12\x19\n\rimages_dir_fd\x18\x01 \x02(\x05:\x02-1\x12\x12\n\nimages_dir\x18\x44 \x01(\t\x12\x0b\n\x03pid\x18\x02 \x01(\x05\x12\x15\n\rleave_running\x18\x03 \x01(\x08\x12\x13\n\x0b\x65xt_unix_sk\x18\x04 \x01(\x08\x12\x17\n\x0ftcp_established\x18\x05 \x01(\x08\x12\x17\n\x0f\x65vasive_devices\x18\x06 \x01(\x08\x12\x11\n\tshell_job\x18\x07 \x01(\x08\x12\x12\n\nfile_locks\x18\x08 \x01(\x08\x12\x14\n\tlog_level\x18\t \x01(\x05:\x01\x32\x12\x10\n\x08log_file\x18\n \x01(\t\x12\"\n\x02ps\x18\x0b \x01(\x0b\x32\x16.criu_page_server_info\x12\x16\n\x0enotify_scripts\x18\x0c \x01(\x08\x12\x0c\n\x04root\x18\r \x01(\t\x12\x12\n\nparent_img\x18\x0e \x01(\t\x12\x11\n\ttrack_mem\x18\x0f \x01(\x08\x12\x12\n\nauto_dedup\x18\x10 \x01(\x08\x12\x13\n\x0bwork_dir_fd\x18\x11 \x01(\x05\x12\x12\n\nlink_remap\x18\x12 \x01(\x08\x12\x1e\n\x05veths\x18\x13 \x03(\x0b\x32\x0f.criu_veth_pair\x12\x1b\n\x07\x63pu_cap\x18\x14 \x01(\r:\n4294967295\x12\x13\n\x0b\x66orce_irmap\x18\x15 \x01(\x08\x12\x10\n\x08\x65xec_cmd\x18\x16 \x03(\t\x12\x1f\n\x07\x65xt_mnt\x18\x17 \x03(\x0b\x32\x0e.ext_mount_map\x12\x16\n\x0emanage_cgroups\x18\x18 \x01(\x08\x12\x1d\n\x07\x63g_root\x18\x19 \x03(\x0b\x32\x0c.cgroup_root\x12\x13\n\x0brst_sibling\x18\x1a \x01(\x08\x12\x1f\n\ninherit_fd\x18\x1b \x03(\x0b\x32\x0b.inherit_fd\x12\x14\n\x0c\x61uto_ext_mnt\x18\x1c \x01(\x08\x12\x13\n\x0b\x65xt_sharing\x18\x1d \x01(\x08\x12\x13\n\x0b\x65xt_masters\x18\x1e \x01(\x08\x12\x10\n\x08skip_mnt\x18\x1f \x03(\t\x12\x11\n\tenable_fs\x18  \x03(\t\x12\x1d\n\x0bunix_sk_ino\x18! \x03(\x0b\x32\x08.unix_sk\x12*\n\x13manage_cgroups_mode\x18\" \x01(\x0e\x32\r.criu_cg_mode\x12\x1c\n\x0bghost_limit\x18# \x01(\r:\x07\x31\x30\x34\x38\x35\x37\x36\x12\x18\n\x10irmap_scan_paths\x18$ \x03(\t\x12\x10\n\x08\x65xternal\x18% \x03(\t\x12\x10\n\x08\x65mpty_ns\x18& \x01(\r\x12 \n\x07join_ns\x18\' \x03(\x0b\x32\x0f.join_namespace\x12\x14\n\x0c\x63group_props\x18) \x01(\t\x12\x19\n\x11\x63group_props_file\x18* \x01(\t\x12\x1e\n\x16\x63group_dump_controller\x18+ \x03(\t\x12\x15\n\rfreeze_cgroup\x18, \x01(\t\x12\x0f\n\x07timeout\x18- \x01(\r\x12\x1a\n\x12tcp_skip_in_flight\x18. \x01(\x08\x12\x14\n\x0cweak_sysctls\x18/ \x01(\x08\x12\x12\n\nlazy_pages\x18\x30 \x01(\x08\x12\x11\n\tstatus_fd\x18\x31 \x01(\x05\x12\x19\n\x11orphan_pts_master\x18\x32 \x01(\x08\x12\x13\n\x0b\x63onfig_file\x18\x33 \x01(\t\x12\x11\n\ttcp_close\x18\x34 \x01(\x08\x12\x13\n\x0blsm_profile\x18\x35 \x01(\t\x12\x12\n\ntls_cacert\x18\x36 \x01(\t\x12\x11\n\ttls_cacrl\x18\x37 \x01(\t\x12\x10\n\x08tls_cert\x18\x38 \x01(\t\x12\x0f\n\x07tls_key\x18\x39 \x01(\t\x12\x0b\n\x03tls\x18: \x01(\x08\x12\x18\n\x10tls_no_cn_verify\x18; \x01(\x08\x12\x13\n\x0b\x63group_yard\x18< \x01(\t\x12\x32\n\rpre_dump_mode\x18= \x01(\x0e\x32\x13.criu_pre_dump_mode:\x06SPLICE\x12\x16\n\x0epidfd_store_sk\x18> \x01(\x05\x12\x19\n\x11lsm_mount_context\x18? \x01(\t\x12\x39\n\x0cnetwork_lock\x18@ \x01(\x0e\x32\x19.criu_network_lock_method:\x08IPTABLES\x12\x19\n\x11mntns_compat_mode\x18\x41 \x01(\x08\x12\x1b\n\x13skip_file_rwx_check\x18\x42 \x01(\x08\x12\x14\n\x0cunprivileged\x18\x43 \x01(\x08\x12\x15\n\rleave_stopped\x18\x45 \x01(\x08\x12\x15\n\rdisplay_stats\x18\x46 \x01(\x08\x12\x15\n\rlog_to_stderr\x18G \x01(\x08\"\"\n\x0e\x63riu_dump_resp\x12\x10\n\x08restored\x18\x01 \x01(\x08\" \n\x11\x63riu_restore_resp\x12\x0b\n\x03pid\x18\x01 \x02(\x05\"*\n\x0b\x63riu_notify\x12\x0e\n\x06script\x18\x01 \x01(\t\x12\x0b\n\x03pid\x18\x02 \x01(\x05\"K\n\rcriu_features\x12\x11\n\tmem_track\x18\x01 \x01(\x08\x12\x12\n\nlazy_pages\x18\x02 \x01(\x08\x12\x13\n\x0bpidfd_store\x18\x03 \x01(\x08\"\x9c\x01\n\x08\x63riu_req\x12\x1c\n\x04type\x18\x01 \x02(\x0e\x32\x0e.criu_req_type\x12\x18\n\x04opts\x18\x02 \x01(\x0b\x32\n.criu_opts\x12\x16\n\x0enotify_success\x18\x03 \x01(\x08\x12\x11\n\tkeep_open\x18\x04 \x01(\x08\x12 \n\x08\x66\x65\x61tures\x18\x05 \x01(\x0b\x32\x0e.criu_features\x12\x0b\n\x03pid\x18\x06 \x01(\r\"\xb7\x02\n\tcriu_resp\x12\x1c\n\x04type\x18\x01 \x02(\x0e\x32\x0e.criu_req_type\x12\x0f\n\x07success\x18\x02 \x02(\x08\x12\x1d\n\x04\x64ump\x18\x03 \x01(\x0b\x32\x0f.criu_dump_resp\x12#\n\x07restore\x18\x04 \x01(\x0b\x32\x12.criu_restore_resp\x12\x1c\n\x06notify\x18\x05 \x01(\x0b\x32\x0c.criu_notify\x12\"\n\x02ps\x18\x06 \x01(\x0b\x32\x16.criu_page_server_info\x12\x10\n\x08\x63r_errno\x18\x07 \x01(\x05\x12 \n\x08\x66\x65\x61tures\x18\x08 \x01(\x0b\x32\x0e.criu_features\x12\x11\n\tcr_errmsg\x18\t \x01(\t\x12\x1e\n\x07version\x18\n \x01(\x0b\x32\r.criu_version\x12\x0e\n\x06status\x18\x0b \x01(\x05\"x\n\x0c\x63riu_version\x12\x14\n\x0cmajor_number\x18\x01 \x02(\x05\x12\x14\n\x0cminor_number\x18\x02 \x02(\x05\x12\r\n\x05gitid\x18\x03 \x01(\t\x12\x10\n\x08sublevel\x18\x04 \x01(\x05\x12\r\n\x05\x65xtra\x18\x05 \x01(\x05\x12\x0c\n\x04name\x18\x06 \x01(\t*_\n\x0c\x63riu_cg_mode\x12\n\n\x06IGNORE\x10\x00\x12\x0b\n\x07\x43G_NONE\x10\x01\x12\t\n\x05PROPS\x10\x02\x12\x08\n\x04SOFT\x10\x03\x12\x08\n\x04\x46ULL\x10\x04\x12\n\n\x06STRICT\x10\x05\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x06*@\n\x18\x63riu_network_lock_method\x12\x0c\n\x08IPTABLES\x10\x01\x12\x0c\n\x08NFTABLES\x10\x02\x12\x08\n\x04SKIP\x10\x03*-\n\x12\x63riu_pre_dump_mode\x12\n\n\x06SPLICE\x10\x01\x12\x0b\n\x07VM_READ\x10\x02*\xe5\x01\n\rcriu_req_type\x12\t\n\x05\x45MPTY\x10\x00\x12\x08\n\x04\x44UMP\x10\x01\x12\x0b\n\x07RESTORE\x10\x02\x12\t\n\x05\x43HECK\x10\x03\x12\x0c\n\x08PRE_DUMP\x10\x04\x12\x0f\n\x0bPAGE_SERVER\x10\x05\x12\n\n\x06NOTIFY\x10\x06\x12\x10\n\x0c\x43PUINFO_DUMP\x10\x07\x12\x11\n\rCPUINFO_CHECK\x10\x08\x12\x11\n\rFEATURE_CHECK\x10\t\x12\x0b\n\x07VERSION\x10\n\x12\x0c\n\x08WAIT_PID\x10\x0b\x12\x14\n\x10PAGE_SERVER_CHLD\x10\x0c\x12\x13\n\x0fSINGLE_PRE_DUMP\x10\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CRIU_CG_MODE']._serialized_start=2852
  _globals['_CRIU_CG_MODE']._serialized_end=2947
  _globals['_CRIU_NETWORK_LOCK_METHOD']._serialized_start=2949
  _globals['_CRIU_NETWORK_LOCK_METHOD']._serialized_end=3013
  _globals['_CRIU_PRE_DUMP_MODE']._serialized_start=3015
  _globals['_CRIU_PRE_DUMP_MODE']._serialized_end=3060
  _globals['_CRIU_REQ_TYPE']._serialized_start=3063
  _globals['_CRIU_REQ_TYPE']._serialized_end=3292
  _globals['_CRIU_PAGE_SERVER_INFO']._serialized_start=13
  _globals['_CRIU_PAGE_SERVER_INFO']._serialized_end=92
  _globals['_CRIU_VETH_PAIR']._serialized_start=94
  _globals['_CRIU_VETH_PAIR']._serialized_end=141
  _globals['_EXT_MOUNT_MAP']._serialized_start=143
  _globals['_EXT_MOUNT_MAP']._serialized_end=184
  _globals['_JOIN_NAMESPACE']._serialized_start=186
  _globals['_JOIN_NAMESPACE']._serialized_end=250
  _globals['_INHERIT_FD']._serialized_start=252
  _globals['_INHERIT_FD']._serialized_end=289
  _globals['_CGROUP_ROOT']._serialized_start=291
  _globals['_CGROUP_ROOT']._serialized_end=332
  _globals['_UNIX_SK']._serialized_start=334
  _globals['_UNIX_SK']._serialized_end=358
  _globals['_CRIU_OPTS']._serialized_start=361
  _globals['_CRIU_OPTS']._serialized_end=2064
  _globals['_CRIU_DUMP_RESP']._serialized_start=2066
  _globals['_CRIU_DUMP_RESP']._serialized_end=2100
  _globals['_CRIU_RESTORE_RESP']._serialized_start=2102
  _globals['_CRIU_RESTORE_RESP']._serialized_end=2134
  _globals['_CRIU_NOTIFY']._serialized_start=2136
  _globals['_CRIU_NOTIFY']._serialized_end=2178
  _globals['_CRIU_FEATURES']._serialized_start=2180
  _globals['_CRIU_FEATURES']._serialized_end=2255
  _globals['_CRIU_REQ']._serialized_start=2258
  _globals['_CRIU_REQ']._serialized_end=2414
  _globals['_CRIU_RESP']._serialized_start=2417
  _globals['_CRIU_RESP']._serialized_end=2728
  _globals['_CRIU_VERSION']._serialized_start=2730
  _globals['_CRIU_VERSION']._serialized_end=2850
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ext-file.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'ext-file.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import fown_pb2 as fown__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x65xt-file.proto\x1a\nfown.proto\"7\n\x0e\x65xt_file_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x19\n\x04\x66own\x18\x05 \x02(\x0b\x32\x0b.fown_entry')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ext_file_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EXT_FILE_ENTRY']._serialized_start=30
  _globals['_EXT_FILE_ENTRY']._serialized_end=85
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: sk-opts.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'sk-opts.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rsk-opts.proto\"\xa4\x04\n\rsk_opts_entry\x12\x11\n\tso_sndbuf\x18\x01 \x02(\r\x12\x11\n\tso_rcvbuf\x18\x02 \x02(\r\x12\x16\n\x0eso_snd_tmo_sec\x18\x03 \x02(\x04\x12\x17\n\x0fso_snd_tmo_usec\x18\x04 \x02(\x04\x12\x16\n\x0eso_rcv_tmo_sec\x18\x05 \x02(\x04\x12\x17\n\x0fso_rcv_tmo_usec\x18\x06 \x02(\x04\x12\x11\n\treuseaddr\x18\x07 \x01(\x08\x12\x13\n\x0bso_priority\x18\x08 \x01(\r\x12\x13\n\x0bso_rcvlowat\x18\t \x01(\r\x12\x0f\n\x07so_mark\x18\n \x01(\r\x12\x13\n\x0bso_passcred\x18\x0b \x01(\x08\x12\x12\n\nso_passsec\x18\x0c \x01(\x08\x12\x14\n\x0cso_dontroute\x18\r \x01(\x08\x12\x13\n\x0bso_no_check\x18\x0e \x01(\x08\x12\x14\n\x0cso_bound_dev\x18\x0f \x01(\t\x12\x11\n\tso_filter\x18\x10 \x03(\x06\x12\x14\n\x0cso_reuseport\x18\x11 \x01(\x08\x12\x14\n\x0cso_broadcast\x18\x12 \x01(\x08\x12\x14\n\x0cso_keepalive\x18\x13 \x01(\x08\x12\x13\n\x0btcp_keepcnt\x18\x14 \x01(\r\x12\x14\n\x0ctcp_keepidle\x18\x15 \x01(\r\x12\x15\n\rtcp_keepintvl\x18\x16 \x01(\r\x12\x14\n\x0cso_oobinline\x18\x17 \x01(\r\x12\x11\n\tso_linger\x18\x18 \x01(\r\x12\x13\n\x0bso_buf_lock\x18\x19 \x01(\r*6\n\x0bsk_shutdown\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04READ\x10\x01\x12\t\n\x05WRITE\x10\x02\x12\x08\n\x04\x42OTH\x10\x03')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sk_opts_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SK_SHUTDOWN']._serialized_start=568
  _globals['_SK_SHUTDOWN']._serialized_end=622
  _globals['_SK_OPTS_ENTRY']._serialized_start=18
  _globals['_SK_OPTS_ENTRY']._serialized_end=566
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: creds.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'creds.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x63reds.proto\"\xcd\x02\n\x0b\x63reds_entry\x12\x0b\n\x03uid\x18\x01 \x02(\r\x12\x0b\n\x03gid\x18\x02 \x02(\r\x12\x0c\n\x04\x65uid\x18\x03 \x02(\r\x12\x0c\n\x04\x65gid\x18\x04 \x02(\r\x12\x0c\n\x04suid\x18\x05 \x02(\r\x12\x0c\n\x04sgid\x18\x06 \x02(\r\x12\r\n\x05\x66suid\x18\x07 \x02(\r\x12\r\n\x05\x66sgid\x18\x08 \x02(\r\x12\x0f\n\x07\x63\x61p_inh\x18\t \x03(\r\x12\x0f\n\x07\x63\x61p_prm\x18\n \x03(\r\x12\x0f\n\x07\x63\x61p_eff\x18\x0b \x03(\r\x12\x0f\n\x07\x63\x61p_bnd\x18\x0c \x03(\r\x12\x0f\n\x07secbits\x18\r \x02(\r\x12\x0e\n\x06groups\x18\x0e \x03(\r\x12\x13\n\x0blsm_profile\x18\x0f \x01(\t\x12\x16\n\x0elsm_sockcreate\x18\x10 \x01(\t\x12\x15\n\rapparmor_data\x18\x11 \x01(\x0c\x12\x14\n\x0cno_new_privs\x18\x12 \x01(\r\x12\x0f\n\x07\x63\x61p_amb\x18\x13 \x03(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'creds_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CREDS_ENTRY']._serialized_start=16
  _globals['_CREDS_ENTRY']._serialized_end=349
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ghost-file.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'ghost-file.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import time_pb2 as time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10ghost-file.proto\x1a\nopts.proto\x1a\ntime.proto\"\xd7\x01\n\x10ghost_file_entry\x12\x0b\n\x03uid\x18\x01 \x02(\r\x12\x0b\n\x03gid\x18\x02 \x02(\r\x12\x0c\n\x04mode\x18\x03 \x02(\r\x12\x12\n\x03\x64\x65v\x18\x04 \x01(\rB\x05\xd2?\x02 \x01\x12\x0b\n\x03ino\x18\x05 \x01(\x04\x12\x15\n\x04rdev\x18\x06 \x01(\rB\x07\xd2?\x04 \x01(\x01\x12\x16\n\x04\x61tim\x18\x07 \x01(\x0b\x32\x08.timeval\x12\x16\n\x04mtim\x18\x08 \x01(\x0b\x32\x08.timeval\x12\x0e\n\x06\x63hunks\x18\t \x01(\x08\x12\x0c\n\x04size\x18\n \x01(\x04\x12\x15\n\rsymlnk_target\x18\x0b \x01(\t\"-\n\x11ghost_chunk_entry\x12\x0b\n\x03len\x18\x01 \x02(\x04\x12\x0b\n\x03off\x18\x02 \x02(\x04')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ghost_file_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GHOST_FILE_ENTRY'].fields_by_name['dev']._loaded_options = None
  _globals['_GHOST_FILE_ENTRY'].fields_by_name['dev']._serialized_options = b'\322?\002 \001'
  _globals['_GHOST_FILE_ENTRY'].fields_by_name['rdev']._loaded_options = None
  _globals['_GHOST_FILE_ENTRY'].fields_by_name['rdev']._serialized_options = b'\322?\004 \001(\001'
  _globals['_GHOST_FILE_ENTRY']._serialized_start=45
  _globals['_GHOST_FILE_ENTRY']._serialized_end=260
  _globals['_GHOST_CHUNK_ENTRY']._serialized_start=262
  _globals['_GHOST_CHUNK_ENTRY']._serialized_end=307
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: sa.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'sa.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x08sa.proto\x1a\nopts.proto\"\xa0\x01\n\x08sa_entry\x12\x18\n\tsigaction\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x14\n\x05\x66lags\x18\x02 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x17\n\x08restorer\x18\x03 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x13\n\x04mask\x18\x04 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x18\n\x10\x63ompat_sigaction\x18\x05 \x01(\x08\x12\x1c\n\rmask_extended\x18\x06 \x01(\x04\x42\x05\xd2?\x02\x08\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sa_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SA_ENTRY'].fields_by_name['sigaction']._loaded_options = None
  _globals['_SA_ENTRY'].fields_by_name['sigaction']._serialized_options = b'\322?\002\010\001'
  _globals['_SA_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_SA_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\002\010\001'
  _globals['_SA_ENTRY'].fields_by_name['restorer']._loaded_options = None
  _globals['_SA_ENTRY'].fields_by_name['restorer']._serialized_options = b'\322?\002\010\001'
  _globals['_SA_ENTRY'].fields_by_name['mask']._loaded_options = None
  _globals['_SA_ENTRY'].fields_by_name['mask']._serialized_options = b'\322?\002\010\001'
  _globals['_SA_ENTRY'].fields_by_name['mask_extended']._loaded_options = None
  _globals['_SA_ENTRY'].fields_by_name['mask_extended']._serialized_options = b'\322?\002\010\001'
  _globals['_SA_ENTRY']._serialized_start=25
  _globals['_SA_ENTRY']._serialized_end=185
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: timens.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'timens.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0ctimens.proto\"+\n\x08timespec\x12\x0e\n\x06tv_sec\x18\x01 \x02(\x04\x12\x0f\n\x07tv_nsec\x18\x02 \x02(\x04\"I\n\x0ctimens_entry\x12\x1c\n\tmonotonic\x18\x01 \x02(\x0b\x32\t.timespec\x12\x1b\n\x08\x62oottime\x18\x02 \x02(\x0b\x32\t.timespec')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'timens_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TIMESPEC']._serialized_start=16
  _globals['_TIMESPEC']._serialized_end=59
  _globals['_TIMENS_ENTRY']._serialized_start=61
  _globals['_TIMENS_ENTRY']._serialized_end=134
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: autofs.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'autofs.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x61utofs.proto\"\x96\x01\n\x0c\x61utofs_entry\x12\n\n\x02\x66\x64\x18\x01 \x02(\x05\x12\x0c\n\x04pgrp\x18\x02 \x02(\x05\x12\x0f\n\x07timeout\x18\x03 \x02(\x05\x12\x10\n\x08minproto\x18\x04 \x02(\x05\x12\x10\n\x08maxproto\x18\x05 \x02(\x05\x12\x0c\n\x04mode\x18\x06 \x02(\x05\x12\x0b\n\x03uid\x18\x07 \x01(\x05\x12\x0b\n\x03gid\x18\x08 \x01(\x05\x12\x0f\n\x07read_fd\x18\t \x01(\x05')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'autofs_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_AUTOFS_ENTRY']._serialized_start=17
  _globals['_AUTOFS_ENTRY']._serialized_end=167
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tun.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'tun.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ttun.proto\x1a\nopts.proto\"L\n\rtunfile_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0e\n\x06netdev\x18\x02 \x01(\t\x12\x10\n\x08\x64\x65tached\x18\x03 \x01(\x08\x12\r\n\x05ns_id\x18\x04 \x01(\r\"e\n\x0etun_link_entry\x12\x14\n\x05\x66lags\x18\x01 \x02(\rB\x05\xd2?\x02\x08\x01\x12\r\n\x05owner\x18\x02 \x02(\x05\x12\r\n\x05group\x18\x03 \x02(\x05\x12\x0f\n\x07vnethdr\x18\x04 \x02(\r\x12\x0e\n\x06sndbuf\x18\x05 \x02(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tun_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TUN_LINK_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_TUN_LINK_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\002\010\001'
  _globals['_TUNFILE_ENTRY']._serialized_start=25
  _globals['_TUNFILE_ENTRY']._serialized_end=101
  _globals['_TUN_LINK_ENTRY']._serialized_start=103
  _globals['_TUN_LINK_ENTRY']._serialized_end=204
# @@protoc_insertion_point(module_scope)



from . import rpc_pb2 as rpc
from . import images
from .criu import criu, CRIUExceptionExternal, CRIUException
from .criu import CR_DEFAULT_SERVICE_ADDRESS
from .version import __version__

__all__ = (
    "rpc",
    "images",
    "criu",
    "CRIUExceptionExternal",
    "CRIUException",
    "CR_DEFAULT_SERVICE_ADDRESS",
    "__version__",
)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: mm.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'mm.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import vma_pb2 as vma__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x08mm.proto\x1a\nopts.proto\x1a\tvma.proto\">\n\x0e\x61io_ring_entry\x12\n\n\x02id\x18\x01 \x02(\x04\x12\x0e\n\x06nr_req\x18\x02 \x02(\r\x12\x10\n\x08ring_len\x18\x03 \x02(\r\"\xce\x03\n\x08mm_entry\x12\x1c\n\rmm_start_code\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x1a\n\x0bmm_end_code\x18\x02 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x1c\n\rmm_start_data\x18\x03 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x1a\n\x0bmm_end_data\x18\x04 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x1d\n\x0emm_start_stack\x18\x05 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x1b\n\x0cmm_start_brk\x18\x06 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x15\n\x06mm_brk\x18\x07 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x1b\n\x0cmm_arg_start\x18\x08 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x19\n\nmm_arg_end\x18\t \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x1b\n\x0cmm_env_start\x18\n \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x19\n\nmm_env_end\x18\x0b \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x13\n\x0b\x65xe_file_id\x18\x0c \x02(\r\x12\x15\n\rmm_saved_auxv\x18\r \x03(\x04\x12\x18\n\x04vmas\x18\x0e \x03(\x0b\x32\n.vma_entry\x12\x10\n\x08\x64umpable\x18\x0f \x01(\x05\x12\x1d\n\x04\x61ios\x18\x10 \x03(\x0b\x32\x0f.aio_ring_entry\x12\x14\n\x0cthp_disabled\x18\x11 \x01(\x08')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mm_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_start_code']._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_start_code']._serialized_options = b'\322?\002\010\001'
  _globals['_MM_ENTRY'].fields_by_name['mm_end_code']._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_end_code']._serialized_options = b'\322?\002\010\001'
  _globals['_MM_ENTRY'].fields_by_name['mm_start_data']._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_start_data']._serialized_options = b'\322?\002\010\001'
  _globals['_MM_ENTRY'].fields_by_name['mm_end_data']._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_end_data']._serialized_options = b'\322?\002\010\001'
  _globals['_MM_ENTRY'].fields_by_name['mm_start_stack']._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_start_stack']._serialized_options = b'\322?\002\010\001'
  _globals['_MM_ENTRY'].fields_by_name['mm_start_brk']._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_start_brk']._serialized_options = b'\322?\002\010\001'
  _globals['_MM_ENTRY'].fields_by_name['mm_brk']._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_brk']._serialized_options = b'\322?\002\010\001'
  _globals['_MM_ENTRY'].fields_by_name['mm_arg_start']._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_arg_start']._serialized_options = b'\322?\002\010\001'
  _globals['_MM_ENTRY'].fields_by_name['mm_arg_end']._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_arg_end']._serialized_options = b'\322?\002\010\001'
  _globals['_MM_ENTRY'].fields_by_name['mm_env_start']._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_env_start']._serialized_options = b'\322?\002\010\001'
  _globals['_MM_ENTRY'].fields_by_name['mm_env_end']._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_env_end']._serialized_options = b'\322?\002\010\001'
  _globals['_AIO_RING_ENTRY']._serialized_start=35
  _globals['_AIO_RING_ENTRY']._serialized_end=97
  _globals['_MM_ENTRY']._serialized_start=100
  _globals['_MM_ENTRY']._serialized_end=562
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fdinfo.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'fdinfo.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import regfile_pb2 as regfile__pb2
import sk_inet_pb2 as sk__inet__pb2
import ns_pb2 as ns__pb2
import packet_sock_pb2 as packet__sock__pb2
import sk_netlink_pb2 as sk__netlink__pb2
import eventfd_pb2 as eventfd__pb2
import eventpoll_pb2 as eventpoll__pb2
import signalfd_pb2 as signalfd__pb2
import tun_pb2 as tun__pb2
import timerfd_pb2 as timerfd__pb2
import fsnotify_pb2 as fsnotify__pb2
import ext_file_pb2 as ext__file__pb2
import sk_unix_pb2 as sk__unix__pb2
import fifo_pb2 as fifo__pb2
import pipe_pb2 as pipe__pb2
import pidfd_pb2 as pidfd__pb2
import tty_pb2 as tty__pb2
import memfd_pb2 as memfd__pb2
import bpfmap_file_pb2 as bpfmap__file__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x66\x64info.proto\x1a\rregfile.proto\x1a\rsk-inet.proto\x1a\x08ns.proto\x1a\x11packet-sock.proto\x1a\x10sk-netlink.proto\x1a\reventfd.proto\x1a\x0f\x65ventpoll.proto\x1a\x0esignalfd.proto\x1a\ttun.proto\x1a\rtimerfd.proto\x1a\x0e\x66snotify.proto\x1a\x0e\x65xt-file.proto\x1a\rsk-unix.proto\x1a\nfifo.proto\x1a\npipe.proto\x1a\x0bpidfd.proto\x1a\ttty.proto\x1a\x0bmemfd.proto\x1a\x11\x62pfmap-file.proto\"n\n\x0c\x66\x64info_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\r\n\x05\x66lags\x18\x02 \x02(\r\x12\x17\n\x04type\x18\x03 \x02(\x0e\x32\t.fd_types\x12\n\n\x02\x66\x64\x18\x04 \x02(\r\x12\x1e\n\x16xattr_security_selinux\x18\x05 \x01(\t\"\xa0\x05\n\nfile_entry\x12\x17\n\x04type\x18\x01 \x02(\x0e\x32\t.fd_types\x12\n\n\x02id\x18\x02 \x02(\r\x12\x1c\n\x03reg\x18\x03 \x01(\x0b\x32\x0f.reg_file_entry\x12\x1b\n\x03isk\x18\x04 \x01(\x0b\x32\x0e.inet_sk_entry\x12\x1b\n\x03nsf\x18\x05 \x01(\x0b\x32\x0e.ns_file_entry\x12\x1f\n\x03psk\x18\x06 \x01(\x0b\x32\x12.packet_sock_entry\x12\x1f\n\x04nlsk\x18\x07 \x01(\x0b\x32\x11.netlink_sk_entry\x12 \n\x03\x65\x66\x64\x18\x08 \x01(\x0b\x32\x13.eventfd_file_entry\x12#\n\x04\x65pfd\x18\t \x01(\x0b\x32\x15.eventpoll_file_entry\x12\x1d\n\x04sgfd\x18\n \x01(\x0b\x32\x0f.signalfd_entry\x12\x1c\n\x04tunf\x18\x0b \x01(\x0b\x32\x0e.tunfile_entry\x12\x1b\n\x03tfd\x18\x0c \x01(\x0b\x32\x0e.timerfd_entry\x12 \n\x03ify\x18\r \x01(\x0b\x32\x13.inotify_file_entry\x12!\n\x03\x66\x66y\x18\x0e \x01(\x0b\x32\x14.fanotify_file_entry\x12\x1c\n\x03\x65xt\x18\x0f \x01(\x0b\x32\x0f.ext_file_entry\x12\x1b\n\x03usk\x18\x10 \x01(\x0b\x32\x0e.unix_sk_entry\x12\x19\n\x04\x66ifo\x18\x11 \x01(\x0b\x32\x0b.fifo_entry\x12\x19\n\x04pipe\x18\x12 \x01(\x0b\x32\x0b.pipe_entry\x12\x1c\n\x03tty\x18\x13 \x01(\x0b\x32\x0f.tty_file_entry\x12 \n\x05memfd\x18\x14 \x01(\x0b\x32\x11.memfd_file_entry\x12\x1f\n\x03\x62pf\x18\x15 \x01(\x0b\x32\x12.bpfmap_file_entry\x12\x1b\n\x05pidfd\x18\x16 \x01(\x0b\x32\x0c.pidfd_entry*\x9f\x02\n\x08\x66\x64_types\x12\x07\n\x03UND\x10\x00\x12\x07\n\x03REG\x10\x01\x12\x08\n\x04PIPE\x10\x02\x12\x08\n\x04\x46IFO\x10\x03\x12\n\n\x06INETSK\x10\x04\x12\n\n\x06UNIXSK\x10\x05\x12\x0b\n\x07\x45VENTFD\x10\x06\x12\r\n\tEVENTPOLL\x10\x07\x12\x0b\n\x07INOTIFY\x10\x08\x12\x0c\n\x08SIGNALFD\x10\t\x12\x0c\n\x08PACKETSK\x10\n\x12\x07\n\x03TTY\x10\x0b\x12\x0c\n\x08\x46\x41NOTIFY\x10\x0c\x12\r\n\tNETLINKSK\x10\r\x12\x06\n\x02NS\x10\x0e\x12\x08\n\x04TUNF\x10\x0f\x12\x07\n\x03\x45XT\x10\x10\x12\x0b\n\x07TIMERFD\x10\x11\x12\t\n\x05MEMFD\x10\x12\x12\n\n\x06\x42PFMAP\x10\x13\x12\t\n\x05PIDFD\x10\x14\x12\r\n\x07\x43TL_TTY\x10\xfe\xff\x03\x12\x11\n\x0b\x41UTOFS_PIPE\x10\xff\xff\x03')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fdinfo_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_FD_TYPES']._serialized_start=1082
  _globals['_FD_TYPES']._serialized_end=1369
  _globals['_FDINFO_ENTRY']._serialized_start=294
  _globals['_FDINFO_ENTRY']._serialized_end=404
  _globals['_FILE_ENTRY']._serialized_start=407
  _globals['_FILE_ENTRY']._serialized_end=1079
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: core-aarch64.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'core-aarch64.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x63ore-aarch64.proto\x1a\nopts.proto\"O\n\x17user_aarch64_regs_entry\x12\x0c\n\x04regs\x18\x01 \x03(\x04\x12\n\n\x02sp\x18\x02 \x02(\x04\x12\n\n\x02pc\x18\x03 \x02(\x04\x12\x0e\n\x06pstate\x18\x04 \x02(\x04\"N\n!user_aarch64_fpsimd_context_entry\x12\r\n\x05vregs\x18\x01 \x03(\x04\x12\x0c\n\x04\x66psr\x18\x02 \x02(\r\x12\x0c\n\x04\x66pcr\x18\x03 \x02(\r\"\xcb\x01\n\x10pac_address_keys\x12\x12\n\napiakey_lo\x18\x01 \x02(\x04\x12\x12\n\napiakey_hi\x18\x02 \x02(\x04\x12\x12\n\napibkey_lo\x18\x03 \x02(\x04\x12\x12\n\napibkey_hi\x18\x04 \x02(\x04\x12\x12\n\napdakey_lo\x18\x05 \x02(\x04\x12\x12\n\napdakey_hi\x18\x06 \x02(\x04\x12\x12\n\napdbkey_lo\x18\x07 \x02(\x04\x12\x12\n\napdbkey_hi\x18\x08 \x02(\x04\x12\x17\n\x0fpac_enabled_key\x18\t \x02(\x04\":\n\x10pac_generic_keys\x12\x12\n\napgakey_lo\x18\x01 \x02(\x04\x12\x12\n\napgakey_hi\x18\x02 \x02(\x04\"d\n\x08pac_keys\x12+\n\x10pac_address_keys\x18\x06 \x01(\x0b\x32\x11.pac_address_keys\x12+\n\x10pac_generic_keys\x18\x07 \x01(\x0b\x32\x11.pac_generic_keys\"\xc3\x01\n\x13thread_info_aarch64\x12\x1d\n\x0e\x63lear_tid_addr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x0b\n\x03tls\x18\x02 \x02(\x04\x12/\n\x06gpregs\x18\x03 \x02(\x0b\x32\x18.user_aarch64_regs_entryB\x05\xd2?\x02\x08\x01\x12\x32\n\x06\x66psimd\x18\x04 \x02(\x0b\x32\".user_aarch64_fpsimd_context_entry\x12\x1b\n\x08pac_keys\x18\x05 \x01(\x0b\x32\t.pac_keys')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core_aarch64_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_THREAD_INFO_AARCH64'].fields_by_name['clear_tid_addr']._loaded_options = None
  _globals['_THREAD_INFO_AARCH64'].fields_by_name['clear_tid_addr']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_AARCH64'].fields_by_name['gpregs']._loaded_options = None
  _globals['_THREAD_INFO_AARCH64'].fields_by_name['gpregs']._serialized_options = b'\322?\002\010\001'
  _globals['_USER_AARCH64_REGS_ENTRY']._serialized_start=34
  _globals['_USER_AARCH64_REGS_ENTRY']._serialized_end=113
  _globals['_USER_AARCH64_FPSIMD_CONTEXT_ENTRY']._serialized_start=115
  _globals['_USER_AARCH64_FPSIMD_CONTEXT_ENTRY']._serialized_end=193
  _globals['_PAC_ADDRESS_KEYS']._serialized_start=196
  _globals['_PAC_ADDRESS_KEYS']._serialized_end=399
  _globals['_PAC_GENERIC_KEYS']._serialized_start=401
  _globals['_PAC_GENERIC_KEYS']._serialized_end=459
  _globals['_PAC_KEYS']._serialized_start=461
  _globals['_PAC_KEYS']._serialized_end=561
  _globals['_THREAD_INFO_AARCH64']._serialized_start=564
  _globals['_THREAD_INFO_AARCH64']._serialized_end=759
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: core-riscv64.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'core-riscv64.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x63ore-riscv64.proto\x1a\nopts.proto\"\x9b\x03\n\x17user_riscv64_regs_entry\x12\n\n\x02pc\x18\x01 \x02(\x04\x12\n\n\x02ra\x18\x02 \x02(\x04\x12\n\n\x02sp\x18\x03 \x02(\x04\x12\n\n\x02gp\x18\x04 \x02(\x04\x12\n\n\x02tp\x18\x05 \x02(\x04\x12\n\n\x02t0\x18\x06 \x02(\x04\x12\n\n\x02t1\x18\x07 \x02(\x04\x12\n\n\x02t2\x18\x08 \x02(\x04\x12\n\n\x02s0\x18\t \x02(\x04\x12\n\n\x02s1\x18\n \x02(\x04\x12\n\n\x02\x61\x30\x18\x0b \x02(\x04\x12\n\n\x02\x61\x31\x18\x0c \x02(\x04\x12\n\n\x02\x61\x32\x18\r \x02(\x04\x12\n\n\x02\x61\x33\x18\x0e \x02(\x04\x12\n\n\x02\x61\x34\x18\x0f \x02(\x04\x12\n\n\x02\x61\x35\x18\x10 \x02(\x04\x12\n\n\x02\x61\x36\x18\x11 \x02(\x04\x12\n\n\x02\x61\x37\x18\x12 \x02(\x04\x12\n\n\x02s2\x18\x13 \x02(\x04\x12\n\n\x02s3\x18\x14 \x02(\x04\x12\n\n\x02s4\x18\x15 \x02(\x04\x12\n\n\x02s5\x18\x16 \x02(\x04\x12\n\n\x02s6\x18\x17 \x02(\x04\x12\n\n\x02s7\x18\x18 \x02(\x04\x12\n\n\x02s8\x18\x19 \x02(\x04\x12\n\n\x02s9\x18\x1a \x02(\x04\x12\x0b\n\x03s10\x18\x1b \x02(\x04\x12\x0b\n\x03s11\x18\x1c \x02(\x04\x12\n\n\x02t3\x18\x1d \x02(\x04\x12\n\n\x02t4\x18\x1e \x02(\x04\x12\n\n\x02t5\x18\x1f \x02(\x04\x12\n\n\x02t6\x18  \x02(\x04\"3\n\x18user_riscv64_d_ext_entry\x12\t\n\x01\x66\x18\x01 \x03(\x04\x12\x0c\n\x04\x66\x63sr\x18\x02 \x02(\r\"\x9d\x01\n\x13thread_info_riscv64\x12\x1d\n\x0e\x63lear_tid_addr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x0b\n\x03tls\x18\x02 \x02(\x04\x12/\n\x06gpregs\x18\x03 \x02(\x0b\x32\x18.user_riscv64_regs_entryB\x05\xd2?\x02\x08\x01\x12)\n\x06\x66psimd\x18\x04 \x02(\x0b\x32\x19.user_riscv64_d_ext_entry')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core_riscv64_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_THREAD_INFO_RISCV64'].fields_by_name['clear_tid_addr']._loaded_options = None
  _globals['_THREAD_INFO_RISCV64'].fields_by_name['clear_tid_addr']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_RISCV64'].fields_by_name['gpregs']._loaded_options = None
  _globals['_THREAD_INFO_RISCV64'].fields_by_name['gpregs']._serialized_options = b'\322?\002\010\001'
  _globals['_USER_RISCV64_REGS_ENTRY']._serialized_start=35
  _globals['_USER_RISCV64_REGS_ENTRY']._serialized_end=446
  _globals['_USER_RISCV64_D_EXT_ENTRY']._serialized_start=448
  _globals['_USER_RISCV64_D_EXT_ENTRY']._serialized_end=499
  _globals['_THREAD_INFO_RISCV64']._serialized_start=502
  _globals['_THREAD_INFO_RISCV64']._serialized_end=659
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: mnt.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'mnt.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tmnt.proto\x1a\nopts.proto\"\xe7\x02\n\tmnt_entry\x12\x0e\n\x06\x66stype\x18\x01 \x02(\r\x12\x0e\n\x06mnt_id\x18\x02 \x02(\r\x12\x17\n\x08root_dev\x18\x03 \x02(\rB\x05\xd2?\x02 \x01\x12\x15\n\rparent_mnt_id\x18\x04 \x02(\r\x12\x14\n\x05\x66lags\x18\x05 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x0c\n\x04root\x18\x06 \x02(\t\x12\x12\n\nmountpoint\x18\x07 \x02(\t\x12\x0e\n\x06source\x18\x08 \x02(\t\x12\x0f\n\x07options\x18\t \x02(\t\x12\x11\n\tshared_id\x18\n \x01(\r\x12\x11\n\tmaster_id\x18\x0b \x01(\r\x12\x13\n\x0bwith_plugin\x18\x0c \x01(\x08\x12\x11\n\text_mount\x18\r \x01(\x08\x12\x0e\n\x06\x66sname\x18\x0e \x01(\t\x12\x18\n\x10internal_sharing\x18\x0f \x01(\x08\x12\x0f\n\x07\x64\x65leted\x18\x10 \x01(\x08\x12\x17\n\x08sb_flags\x18\x11 \x01(\rB\x05\xd2?\x02\x08\x01\x12\x0f\n\x07\x65xt_key\x18\x12 \x01(\t*\x90\x02\n\x06\x66stype\x12\x0f\n\x0bUNSUPPORTED\x10\x00\x12\x08\n\x04PROC\x10\x01\x12\t\n\x05SYSFS\x10\x02\x12\x0c\n\x08\x44\x45VTMPFS\x10\x03\x12\x0f\n\x0b\x42INFMT_MISC\x10\x04\x12\t\n\x05TMPFS\x10\x05\x12\n\n\x06\x44\x45VPTS\x10\x06\x12\t\n\x05SIMFS\x10\x07\x12\n\n\x06PSTORE\x10\x08\x12\x0e\n\nSECURITYFS\x10\t\x12\x0b\n\x07\x46USECTL\x10\n\x12\x0b\n\x07\x44\x45\x42UGFS\x10\x0b\x12\n\n\x06\x43GROUP\x10\x0c\x12\x08\n\x04\x41UFS\x10\r\x12\n\n\x06MQUEUE\x10\x0e\x12\x08\n\x04\x46USE\x10\x0f\x12\x08\n\x04\x41UTO\x10\x10\x12\r\n\tOVERLAYFS\x10\x11\x12\n\n\x06\x41UTOFS\x10\x12\x12\x0b\n\x07TRACEFS\x10\x13\x12\x0b\n\x07\x43GROUP2\x10\x17')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mnt_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MNT_ENTRY'].fields_by_name['root_dev']._loaded_options = None
  _globals['_MNT_ENTRY'].fields_by_name['root_dev']._serialized_options = b'\322?\002 \001'
  _globals['_MNT_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_MNT_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\002\010\001'
  _globals['_MNT_ENTRY'].fields_by_name['sb_flags']._loaded_options = None
  _globals['_MNT_ENTRY'].fields_by_name['sb_flags']._serialized_options = b'\322?\002\010\001'
  _globals['_FSTYPE']._serialized_start=388
  _globals['_FSTYPE']._serialized_end=660
  _globals['_MNT_ENTRY']._serialized_start=26
  _globals['_MNT_ENTRY']._serialized_end=385
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: core-ppc64.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'core-ppc64.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x63ore-ppc64.proto\x1a\nopts.proto\"\xc2\x01\n\x15user_ppc64_regs_entry\x12\x0b\n\x03gpr\x18\x01 \x03(\x04\x12\x0b\n\x03nip\x18\x02 \x02(\x04\x12\x0b\n\x03msr\x18\x03 \x02(\x04\x12\x11\n\torig_gpr3\x18\x04 \x02(\x04\x12\x0b\n\x03\x63tr\x18\x05 \x02(\x04\x12\x0c\n\x04link\x18\x06 \x02(\x04\x12\x0b\n\x03xer\x18\x07 \x02(\x04\x12\x0b\n\x03\x63\x63r\x18\x08 \x02(\x04\x12\x0c\n\x04trap\x18\t \x02(\x04\x12\x0e\n\x06texasr\x18\n \x01(\x04\x12\r\n\x05tfhar\x18\x0b \x01(\x04\x12\r\n\x05tfiar\x18\x0c \x01(\x04\"*\n\x18user_ppc64_fpstate_entry\x12\x0e\n\x06\x66pregs\x18\x01 \x03(\x04\":\n\x18user_ppc64_vrstate_entry\x12\x0e\n\x06vrregs\x18\x01 \x03(\x04\x12\x0e\n\x06vrsave\x18\x02 \x02(\r\",\n\x19user_ppc64_vsxstate_entry\x12\x0f\n\x07vsxregs\x18\x01 \x03(\x04\"\xc8\x01\n\x18user_ppc64_tm_regs_entry\x12&\n\x06gpregs\x18\x01 \x02(\x0b\x32\x16.user_ppc64_regs_entry\x12*\n\x07\x66pstate\x18\x02 \x01(\x0b\x32\x19.user_ppc64_fpstate_entry\x12*\n\x07vrstate\x18\x03 \x01(\x0b\x32\x19.user_ppc64_vrstate_entry\x12,\n\x08vsxstate\x18\x04 \x01(\x0b\x32\x1a.user_ppc64_vsxstate_entry\"\x93\x02\n\x11thread_info_ppc64\x12\x1d\n\x0e\x63lear_tid_addr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12-\n\x06gpregs\x18\x02 \x02(\x0b\x32\x16.user_ppc64_regs_entryB\x05\xd2?\x02\x08\x01\x12*\n\x07\x66pstate\x18\x03 \x01(\x0b\x32\x19.user_ppc64_fpstate_entry\x12*\n\x07vrstate\x18\x04 \x01(\x0b\x32\x19.user_ppc64_vrstate_entry\x12,\n\x08vsxstate\x18\x05 \x01(\x0b\x32\x1a.user_ppc64_vsxstate_entry\x12*\n\x07tmstate\x18\x06 \x01(\x0b\x32\x19.user_ppc64_tm_regs_entry')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core_ppc64_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_THREAD_INFO_PPC64'].fields_by_name['clear_tid_addr']._loaded_options = None
  _globals['_THREAD_INFO_PPC64'].fields_by_name['clear_tid_addr']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_PPC64'].fields_by_name['gpregs']._loaded_options = None
  _globals['_THREAD_INFO_PPC64'].fields_by_name['gpregs']._serialized_options = b'\322?\002\010\001'
  _globals['_USER_PPC64_REGS_ENTRY']._serialized_start=33
  _globals['_USER_PPC64_REGS_ENTRY']._serialized_end=227
  _globals['_USER_PPC64_FPSTATE_ENTRY']._serialized_start=229
  _globals['_USER_PPC64_FPSTATE_ENTRY']._serialized_end=271
  _globals['_USER_PPC64_VRSTATE_ENTRY']._serialized_start=273
  _globals['_USER_PPC64_VRSTATE_ENTRY']._serialized_end=331
  _globals['_USER_PPC64_VSXSTATE_ENTRY']._serialized_start=333
  _globals['_USER_PPC64_VSXSTATE_ENTRY']._serialized_end=377
  _globals['_USER_PPC64_TM_REGS_ENTRY']._serialized_start=380
  _globals['_USER_PPC64_TM_REGS_ENTRY']._serialized_end=580
  _globals['_THREAD_INFO_PPC64']._serialized_start=583
  _globals['_THREAD_INFO_PPC64']._serialized_end=858
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: timer.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'timer.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0btimer.proto\"H\n\x0citimer_entry\x12\x0c\n\x04isec\x18\x01 \x02(\x04\x12\r\n\x05iusec\x18\x02 \x02(\x04\x12\x0c\n\x04vsec\x18\x03 \x02(\x04\x12\r\n\x05vusec\x18\x04 \x02(\x04\"\xd7\x01\n\x11posix_timer_entry\x12\r\n\x05it_id\x18\x01 \x02(\r\x12\x10\n\x08\x63lock_id\x18\x02 \x02(\r\x12\x10\n\x08si_signo\x18\x03 \x02(\r\x12\x17\n\x0fit_sigev_notify\x18\x04 \x02(\r\x12\x11\n\tsival_ptr\x18\x05 \x02(\x04\x12\x0f\n\x07overrun\x18\x06 \x02(\r\x12\x0c\n\x04isec\x18\x07 \x02(\x04\x12\r\n\x05insec\x18\x08 \x02(\x04\x12\x0c\n\x04vsec\x18\t \x02(\x04\x12\r\n\x05vnsec\x18\n \x02(\x04\x12\x18\n\x10notify_thread_id\x18\x0b \x01(\x05\"\x8d\x01\n\x11task_timers_entry\x12\x1b\n\x04real\x18\x01 \x02(\x0b\x32\r.itimer_entry\x12\x1b\n\x04virt\x18\x02 \x02(\x0b\x32\r.itimer_entry\x12\x1b\n\x04prof\x18\x03 \x02(\x0b\x32\r.itimer_entry\x12!\n\x05posix\x18\x04 \x03(\x0b\x32\x12.posix_timer_entry')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'timer_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ITIMER_ENTRY']._serialized_start=15
  _globals['_ITIMER_ENTRY']._serialized_end=87
  _globals['_POSIX_TIMER_ENTRY']._serialized_start=90
  _globals['_POSIX_TIMER_ENTRY']._serialized_end=305
  _globals['_TASK_TIMERS_ENTRY']._serialized_start=308
  _globals['_TASK_TIMERS_ENTRY']._serialized_end=449
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: core-arm.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'core-arm.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x63ore-arm.proto\x1a\nopts.proto\"\xf5\x01\n\x13user_arm_regs_entry\x12\n\n\x02r0\x18\x01 \x02(\r\x12\n\n\x02r1\x18\x02 \x02(\r\x12\n\n\x02r2\x18\x03 \x02(\r\x12\n\n\x02r3\x18\x04 \x02(\r\x12\n\n\x02r4\x18\x05 \x02(\r\x12\n\n\x02r5\x18\x06 \x02(\r\x12\n\n\x02r6\x18\x07 \x02(\r\x12\n\n\x02r7\x18\x08 \x02(\r\x12\n\n\x02r8\x18\t \x02(\r\x12\n\n\x02r9\x18\n \x02(\r\x12\x0b\n\x03r10\x18\x0b \x02(\r\x12\n\n\x02\x66p\x18\x0c \x02(\r\x12\n\n\x02ip\x18\r \x02(\r\x12\n\n\x02sp\x18\x0e \x02(\r\x12\n\n\x02lr\x18\x0f \x02(\r\x12\n\n\x02pc\x18\x10 \x02(\r\x12\x0c\n\x04\x63psr\x18\x11 \x02(\r\x12\x0f\n\x07orig_r0\x18\x12 \x02(\r\"j\n\x17user_arm_vfpstate_entry\x12\x10\n\x08vfp_regs\x18\x01 \x03(\x04\x12\r\n\x05\x66pscr\x18\x02 \x02(\r\x12\r\n\x05\x66pexc\x18\x03 \x02(\r\x12\x0e\n\x06\x66pinst\x18\x04 \x02(\r\x12\x0f\n\x07\x66pinst2\x18\x05 \x02(\r\"\x95\x01\n\x0fthread_info_arm\x12\x1d\n\x0e\x63lear_tid_addr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x0b\n\x03tls\x18\x02 \x02(\r\x12+\n\x06gpregs\x18\x03 \x02(\x0b\x32\x14.user_arm_regs_entryB\x05\xd2?\x02\x08\x01\x12)\n\x07\x66pstate\x18\x04 \x02(\x0b\x32\x18.user_arm_vfpstate_entry')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core_arm_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_THREAD_INFO_ARM'].fields_by_name['clear_tid_addr']._loaded_options = None
  _globals['_THREAD_INFO_ARM'].fields_by_name['clear_tid_addr']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_ARM'].fields_by_name['gpregs']._loaded_options = None
  _globals['_THREAD_INFO_ARM'].fields_by_name['gpregs']._serialized_options = b'\322?\002\010\001'
  _globals['_USER_ARM_REGS_ENTRY']._serialized_start=31
  _globals['_USER_ARM_REGS_ENTRY']._serialized_end=276
  _globals['_USER_ARM_VFPSTATE_ENTRY']._serialized_start=278
  _globals['_USER_ARM_VFPSTATE_ENTRY']._serialized_end=384
  _globals['_THREAD_INFO_ARM']._serialized_start=387
  _globals['_THREAD_INFO_ARM']._serialized_end=536
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fh.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'fh.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x08\x66h.proto\x1a\nopts.proto\"U\n\x08\x66h_entry\x12\r\n\x05\x62ytes\x18\x01 \x02(\r\x12\x0c\n\x04type\x18\x02 \x02(\r\x12\x0e\n\x06handle\x18\x03 \x03(\x04\x12\x0c\n\x04path\x18\x04 \x01(\t\x12\x0e\n\x06mnt_id\x18\x05 \x01(\r\"F\n\x11irmap_cache_entry\x12\x14\n\x03\x64\x65v\x18\x01 \x02(\rB\x07\xd2?\x04 \x01(\x01\x12\r\n\x05inode\x18\x02 \x02(\x04\x12\x0c\n\x04path\x18\x03 \x02(\t*!\n\x0e\x66h_entry_sizes\x12\x0f\n\x0bmin_entries\x10\x10')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fh_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_IRMAP_CACHE_ENTRY'].fields_by_name['dev']._loaded_options = None
  _globals['_IRMAP_CACHE_ENTRY'].fields_by_name['dev']._serialized_options = b'\322?\004 \001(\001'
  _globals['_FH_ENTRY_SIZES']._serialized_start=183
  _globals['_FH_ENTRY_SIZES']._serialized_end=216
  _globals['_FH_ENTRY']._serialized_start=24
  _globals['_FH_ENTRY']._serialized_end=109
  _globals['_IRMAP_CACHE_ENTRY']._serialized_start=111
  _globals['_IRMAP_CACHE_ENTRY']._serialized_end=181
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: inventory.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'inventory.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import core_pb2 as core__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0finventory.proto\x1a\ncore.proto\" \n\rplugins_entry\x12\x0f\n\x07plugins\x18\x0c \x03(\t\"\xdc\x02\n\x0finventory_entry\x12\x13\n\x0bimg_version\x18\x01 \x02(\r\x12\x15\n\rfdinfo_per_id\x18\x02 \x01(\x08\x12&\n\x08root_ids\x18\x03 \x01(\x0b\x32\x14.task_kobj_ids_entry\x12\x11\n\tns_per_id\x18\x04 \x01(\x08\x12\x13\n\x0broot_cg_set\x18\x05 \x01(\r\x12\x19\n\x07lsmtype\x18\x06 \x01(\x0e\x32\x08.lsmtype\x12\x13\n\x0b\x64ump_uptime\x18\x08 \x01(\x04\x12\x15\n\rpre_dump_mode\x18\t \x01(\r\x12\x11\n\ttcp_close\x18\n \x01(\x08\x12\x1b\n\x13network_lock_method\x18\x0b \x01(\r\x12%\n\rplugins_entry\x18\x0c \x01(\x0b\x32\x0e.plugins_entry\x12\x18\n\x10\x64ump_criu_run_id\x18\r \x01(\t\x12\x15\n\rallow_uprobes\x18\x0e \x01(\x08*0\n\x07lsmtype\x12\n\n\x06NO_LSM\x10\x00\x12\x0b\n\x07SELINUX\x10\x01\x12\x0c\n\x08\x41PPARMOR\x10\x02')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'inventory_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_LSMTYPE']._serialized_start=416
  _globals['_LSMTYPE']._serialized_end=464
  _globals['_PLUGINS_ENTRY']._serialized_start=31
  _globals['_PLUGINS_ENTRY']._serialized_end=63
  _globals['_INVENTORY_ENTRY']._serialized_start=66
  _globals['_INVENTORY_ENTRY']._serialized_end=414
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: packet-sock.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'packet-sock.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fown_pb2 as fown__pb2
import sk_opts_pb2 as sk__opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11packet-sock.proto\x1a\nopts.proto\x1a\nfown.proto\x1a\rsk-opts.proto\":\n\rpacket_mclist\x12\r\n\x05index\x18\x01 \x02(\r\x12\x0c\n\x04type\x18\x02 \x02(\r\x12\x0c\n\x04\x61\x64\x64r\x18\x03 \x02(\x0c\"\x94\x01\n\x0bpacket_ring\x12\x12\n\nblock_size\x18\x01 \x02(\r\x12\x10\n\x08\x62lock_nr\x18\x02 \x02(\r\x12\x12\n\nframe_size\x18\x03 \x02(\r\x12\x10\n\x08\x66rame_nr\x18\x04 \x02(\r\x12\x12\n\nretire_tmo\x18\x05 \x02(\r\x12\x13\n\x0bsizeof_priv\x18\x06 \x02(\r\x12\x10\n\x08\x66\x65\x61tures\x18\x07 \x02(\r\"\xb6\x03\n\x11packet_sock_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0c\n\x04type\x18\x02 \x02(\r\x12\x10\n\x08protocol\x18\x03 \x02(\r\x12\x14\n\x05\x66lags\x18\x04 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x0f\n\x07ifindex\x18\x05 \x02(\r\x12\x19\n\x04\x66own\x18\x06 \x02(\x0b\x32\x0b.fown_entry\x12\x1c\n\x04opts\x18\x07 \x02(\x0b\x32\x0e.sk_opts_entry\x12\x0f\n\x07version\x18\x08 \x02(\r\x12\x0f\n\x07reserve\x18\t \x02(\r\x12\x10\n\x08\x61ux_data\x18\n \x02(\x08\x12\x10\n\x08orig_dev\x18\x0b \x02(\x08\x12\x10\n\x08vnet_hdr\x18\x0c \x02(\x08\x12\x0c\n\x04loss\x18\r \x02(\x08\x12\x11\n\ttimestamp\x18\x0e \x02(\r\x12\x13\n\x0b\x63opy_thresh\x18\x0f \x02(\r\x12\x1e\n\x06mclist\x18\x10 \x03(\x0b\x32\x0e.packet_mclist\x12\x1a\n\x06\x66\x61nout\x18\x11 \x01(\r:\n4294967295\x12\x1d\n\x07rx_ring\x18\x12 \x01(\x0b\x32\x0c.packet_ring\x12\x1d\n\x07tx_ring\x18\x13 \x01(\x0b\x32\x0c.packet_ring\x12\r\n\x05ns_id\x18\x14 \x01(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'packet_sock_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PACKET_SOCK_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_PACKET_SOCK_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\002\010\001'
  _globals['_PACKET_MCLIST']._serialized_start=60
  _globals['_PACKET_MCLIST']._serialized_end=118
  _globals['_PACKET_RING']._serialized_start=121
  _globals['_PACKET_RING']._serialized_end=269
  _globals['_PACKET_SOCK_ENTRY']._serialized_start=272
  _globals['_PACKET_SOCK_ENTRY']._serialized_end=710
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: sk-netlink.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'sk-netlink.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fown_pb2 as fown__pb2
import sk_opts_pb2 as sk__opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10sk-netlink.proto\x1a\nopts.proto\x1a\nfown.proto\x1a\rsk-opts.proto\"\xf1\x01\n\x10netlink_sk_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0b\n\x03ino\x18\x02 \x02(\r\x12\x10\n\x08protocol\x18\x03 \x02(\r\x12\r\n\x05state\x18\x04 \x02(\r\x12\x14\n\x05\x66lags\x18\x06 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x0e\n\x06portid\x18\x07 \x02(\r\x12\x0e\n\x06groups\x18\x08 \x03(\r\x12\x12\n\ndst_portid\x18\t \x02(\r\x12\x11\n\tdst_group\x18\n \x02(\r\x12\x19\n\x04\x66own\x18\x0b \x02(\x0b\x32\x0b.fown_entry\x12\x1c\n\x04opts\x18\x0c \x02(\x0b\x32\x0e.sk_opts_entry\x12\r\n\x05ns_id\x18\r \x01(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sk_netlink_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_NETLINK_SK_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_NETLINK_SK_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\002\010\001'
  _globals['_NETLINK_SK_ENTRY']._serialized_start=60
  _globals['_NETLINK_SK_ENTRY']._serialized_end=301
# @@protoc_insertion_point(module_scope)
